source parray.tcl
source stooop.tcl
namespace import stooop::*

### check basic cloning operation (see nested class version in 70.tcl)

# expected output:

## a::(1,x) = 0
## a::(2,x) = 0

## A::(3,x) = 0
## A::(4,x) = 0

class a {}
proc a::a {this} {
    set ($this,x) 0
}
new [new a]
printArrays a::

class A {
    proc A {this} {
        set ($this,x) 0
    }
}
new [new A]
printArrays A::
